@@ -3,8 +3,7 @@ package test
 import (
 	"testing"
 
-	"github.com/tfsec/tfsec/internal/app/tfsec/checks"
-	"github.com/tfsec/tfsec/internal/app/tfsec/scanner"
+	"github.com/tfsec/tfsec/internal/app/tfsec/rules"
 )
 
 func Test_AWSBlockPublicPolicyS3(t *testing.T) {
@@ -12,20 +11,20 @@ func Test_AWSBlockPublicPolicyS3(t *testing.T) {
 	var tests = []struct {
 		name                  string
 		source                string
-		mustIncludeResultCode scanner.RuleCode
-		mustExcludeResultCode scanner.RuleCode
+		mustIncludeResultCode string
+		mustExcludeResultCode string
 	}{
 		{
-			name: "Check fails when block_public_policy not set, defaults to false",
+			name: "Rule fails when block_public_policy not set, defaults to false",
 			source: `
 resource "aws_s3_bucket_public_access_block" "bad_example" {
 	bucket = aws_s3_bucket.example.id
 }
 `,
-			mustIncludeResultCode: checks.AWSBlockPublicPolicyS3,
+			mustIncludeResultCode: rules.AWSBlockPublicPolicyS3,
 		},
 		{
-			name: "Check fails when block_public_policy set but is false",
+			name: "Rule fails when block_public_policy set but is false",
 			source: `
 resource "aws_s3_bucket_public_access_block" "bad_example" {
 	bucket = aws_s3_bucket.example.id
@@ -33,10 +32,10 @@ resource "aws_s3_bucket_public_access_block" "bad_example" {
 	block_public_policy = false
 }
 `,
-			mustIncludeResultCode: checks.AWSBlockPublicPolicyS3,
+			mustIncludeResultCode: rules.AWSBlockPublicPolicyS3,
 		},
 		{
-			name: "Check passes when block_public_policy is true",
+			name: "Rule passes when block_public_policy is true",
 			source: `
 resource "aws_s3_bucket_public_access_block" "bad_example" {
 	bucket = aws_s3_bucket.example.id
@@ -44,7 +43,7 @@ resource "aws_s3_bucket_public_access_block" "bad_example" {
 	block_public_policy = true
 }
 `,
-			mustExcludeResultCode: checks.AWSBlockPublicPolicyS3,
+			mustExcludeResultCode: rules.AWSBlockPublicPolicyS3,
 		},
 	}
 
