@@ -3,6 +3,7 @@ package rule
 import (
 	"github.com/tfsec/tfsec/pkg/provider"
 	"github.com/tfsec/tfsec/pkg/result"
+	"github.com/tfsec/tfsec/pkg/severity"
 
 	"github.com/tfsec/tfsec/internal/app/tfsec/block"
 	"github.com/tfsec/tfsec/internal/app/tfsec/hclcontext"
@@ -11,12 +12,13 @@ import (
 // Rule is a targeted security test which can be applied to terraform templates. It includes the types to run on e.g.
 // "resource", and the labels to run on e.g. "aws_s3_bucket".
 type Rule struct {
-	ID             string
-	Documentation  RuleDocumentation
-	Provider       provider.Provider
-	RequiredTypes  []string
-	RequiredLabels []string
-	CheckFunc      func(result.Set, *block.Block, *hclcontext.Context)
+	ID              string
+	Documentation   RuleDocumentation
+	Provider        provider.Provider
+	RequiredTypes   []string
+	RequiredLabels  []string
+	DefaultSeverity severity.Severity
+	CheckFunc       func(result.Set, *block.Block, *hclcontext.Context)
 }
 
 type RuleDocumentation struct {
